@@ -13,17 +13,18 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-from oslo_log import log as logging
-
-from designate.backend import base
+from designate.openstack.common import log as logging
+from designate.plugin import Plugin
 
 LOG = logging.getLogger(__name__)
 
 
-def get_backend(type_, target):
-    # TODO(kiall): Type is attached to the target, use it.
-    LOG.debug("Loading backend driver: %s" % type_)
+def get_backend(backend_driver, central_service):
+    LOG.debug("Loading backend driver: %s" % backend_driver)
 
-    cls = base.Backend.get_driver(type_)
+    invoke_kwds = {
+        'central_service': central_service
+    }
 
-    return cls(target)
+    return Plugin.get_plugin(backend_driver, ns=__name__, invoke_on_load=True,
+                             invoke_kwds=invoke_kwds)
