@@ -1,6 +1,6 @@
 # Copyright 2013 Hewlett-Packard Development Company, L.P.
 #
-# Author: Kiall Mac Innes <kiall@hpe.com>
+# Author: Kiall Mac Innes <kiall@hp.com>
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -14,68 +14,54 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 import abc
-
-import designate.conf
+from oslo.config import cfg
 from designate import exceptions
-from designate.plugin import DriverPlugin
+from designate.plugin import Plugin
 
 
-CONF = designate.conf.CONF
-
-
-class Quota(DriverPlugin, metaclass=abc.ABCMeta):
-    """Base class for quota plugins"""
+class Quota(Plugin):
+    """ Base class for quota plugins """
+    __metaclass__ = abc.ABCMeta
     __plugin_ns__ = 'designate.quota'
     __plugin_type__ = 'quota'
 
     def limit_check(self, context, tenant_id, **values):
-        resources_exceeded = []
         quotas = self.get_quotas(context, tenant_id)
 
         for resource, value in values.items():
             if resource in quotas:
-                # Setting the resource quota to a negative value will make
-                # the resource unlimited
-                if quotas[resource] >= 0 and value > quotas[resource]:
-                    resources_exceeded.append(resource)
+                if value >= quotas[resource]:
+                    raise exceptions.OverQuota()
             else:
-                raise exceptions.QuotaResourceUnknown(
-                    f"'{resource}' is not a valid quota resource."
-                )
-
-        if resources_exceeded:
-            resources_exceeded.sort(key=len)
-            raise exceptions.OverQuota(
-                'Quota exceeded for %s.' % ', '.join(resources_exceeded)
-            )
+                raise exceptions.QuotaResourceUnknown()
 
     def get_quotas(self, context, tenant_id):
         quotas = self.get_default_quotas(context)
+
         quotas.update(self._get_quotas(context, tenant_id))
 
         return quotas
 
-    def get_default_quotas(self, context):
-        return {
-            'zones': CONF.quota_zones,
-            'zone_recordsets': CONF.quota_zone_recordsets,
-            'zone_records': CONF.quota_zone_records,
-            'recordset_records': CONF.quota_recordset_records,
-            'api_export_size': CONF.quota_api_export_size,
-        }
-
     @abc.abstractmethod
     def _get_quotas(self, context, tenant_id):
-        """Internal Get Quotas used by get_quotas"""
+        pass
+
+    def get_default_quotas(self, context):
+        return {
+            'domains': cfg.CONF.quota_domains,
+            'domain_records': cfg.CONF.quota_domain_records,
+        }
 
-    @abc.abstractmethod
     def get_quota(self, context, tenant_id, resource):
-        """Get Quota"""
+        quotas = self._get_quotas(context, tenant_id)
+
+        if resource not in quotas:
+            raise exceptions.QuotaResourceUnknown()
+
+        return quotas[resource]
 
-    @abc.abstractmethod
     def set_quota(self, context, tenant_id, resource, hard_limit):
-        """Set Quota"""
+        raise NotImplementedError()
 
-    @abc.abstractmethod
     def reset_quotas(self, context, tenant_id):
-        """Reset Quotas"""
+        raise NotImplementedError()
