@@ -1,6 +1,6 @@
-# Copyright 2014 Rackspace Inc.
+# Copyright 2012 Hewlett-Packard Development Company, L.P. All Rights Reserved.
 #
-# Author: Tim Simmons <tim.simmons@rackspace.com>
+# Author: Kiall Mac Innes <kiall@hp.com>
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -17,14 +17,13 @@ from designate.tests.test_agent import AgentTestCase
 
 
 class AgentServiceTest(AgentTestCase):
+    __test__ = True
+
     def setUp(self):
         super(AgentServiceTest, self).setUp()
+        self.service = self.get_agent_service()
 
-        # Use a random port
-        self.config(port=0, group='service:agent')
-
-        self.service = self.start_service('agent')
-
-    def test_stop(self):
-        # NOTE: Start is already done by the fixture in start_service()
+    def test_start_and_stop(self):
+        # Ensures the start/stop actions don't raise
+        self.service.start()
         self.service.stop()
