@@ -13,9 +13,8 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-from oslo_log import log as logging
-from oslo_serialization import jsonutils as json
-
+from designate.openstack.common import log as logging
+from designate.openstack.common import jsonutils as json
 from designate.api import v1 as api_v1
 from designate.api import middleware
 from designate.tests.test_api import ApiTestCase
@@ -25,6 +24,8 @@ LOG = logging.getLogger(__name__)
 
 
 class ApiV1Test(ApiTestCase):
+    __test__ = False
+
     def setUp(self):
         super(ApiV1Test, self).setUp()
 
@@ -34,26 +35,25 @@ class ApiV1Test(ApiTestCase):
         # Create the application
         self.app = api_v1.factory({})
 
-        # Inject the NormalizeURIMiddleware middleware
-        self.app.wsgi_app = middleware.NormalizeURIMiddleware(
-            self.app.wsgi_app)
-
         # Inject the FaultWrapper middleware
         self.app.wsgi_app = middleware.FaultWrapperMiddleware(
             self.app.wsgi_app)
 
-        # Inject the ValidationError middleware
-        self.app.wsgi_app = middleware.APIv1ValidationErrorMiddleware(
+        # Inject the NoAuth middleware
+        self.app.wsgi_app = middleware.NoAuthContextMiddleware(
             self.app.wsgi_app)
 
-        # Inject the TestAuth middleware
-        self.app.wsgi_app = middleware.TestContextMiddleware(
-            self.app.wsgi_app, self.admin_context.tenant,
-            self.admin_context.user)
-
         # Obtain a test client
         self.client = self.app.test_client()
 
+        # Create and start an instance of the central service
+        self.central_service = self.get_central_service()
+        self.central_service.start()
+
+    def tearDown(self):
+        self.central_service.stop()
+        super(ApiV1Test, self).tearDown()
+
     def get(self, path, **kw):
         expected_status_code = kw.pop('status_code', 200)
 
@@ -61,7 +61,7 @@ class ApiV1Test(ApiTestCase):
 
         LOG.debug('Response Body: %r' % resp.data)
 
-        self.assertEqual(expected_status_code, resp.status_code)
+        self.assertEqual(resp.status_code, expected_status_code)
 
         try:
             resp.json = json.loads(resp.data)
@@ -79,7 +79,7 @@ class ApiV1Test(ApiTestCase):
 
         LOG.debug('Response Body: %r' % resp.data)
 
-        self.assertEqual(expected_status_code, resp.status_code)
+        self.assertEqual(resp.status_code, expected_status_code)
 
         try:
             resp.json = json.loads(resp.data)
@@ -97,7 +97,7 @@ class ApiV1Test(ApiTestCase):
 
         LOG.debug('Response Body: %r' % resp.data)
 
-        self.assertEqual(expected_status_code, resp.status_code)
+        self.assertEqual(resp.status_code, expected_status_code)
 
         try:
             resp.json = json.loads(resp.data)
@@ -113,6 +113,6 @@ class ApiV1Test(ApiTestCase):
 
         LOG.debug('Response Body: %r' % resp.data)
 
-        self.assertEqual(expected_status_code, resp.status_code)
+        self.assertEqual(resp.status_code, expected_status_code)
 
         return resp
