@@ -1,6 +1,6 @@
-# Copyright 2015 Hewlett-Packard Development Company, L.P.
+# Copyright 2012 Managed I.T.
 #
-# Author: Kiall Mac Innes <kiall@hpe.com>
+# Author: Kiall Mac Innes <kiall@managedit.ie>
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -13,8 +13,21 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
+from oslo.config import cfg
+from designate.openstack.common import log as logging
 from designate.tests import TestCase
+from designate import backend
+
+LOG = logging.getLogger(__name__)
 
 
 class BackendTestCase(TestCase):
-    pass
+    __test__ = False
+
+    def get_backend_driver(self):
+        central_service = self.get_central_service()
+        return backend.get_backend(cfg.CONF['service:agent'].backend_driver,
+                                   central_service=central_service)
+
+    def test_constructor(self):
+        self.get_backend_driver()
